# Abi-Core: Array Basic Implementations
### Tired of having to reinvent the wheel? Try Abi-Core

Abi-Core contains a collection of array initializations,
sorts,and other frequently-repeated tasks to help trim down on
repetitive tasks.

Abi-Core currently includes these sorting algorithms each with an optional boolean to display a real-time sorting graphic:
<ul>
    <li>Bubble</li>
    <li>Insertion</li>
    <li>Merge</li>
    <li>Selection</li>
</ul>

As well as:
<ul>
    <li>Initializations of empty, random, and uniformly filled n-dimensional arrays of any defined type</li>
    <li>Searches for all indices of a query, nth greatest/least, nth occurrence, unique, and intersections with another array</li>
    <li>Transformations such as flattening/chunking, concatenating into one string, reversal, sliding window, duplicate removal, and zipping</li>
</ul>